==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-dock-manager-layout.js <==
import { __extends, __values } from "tslib";
import * as React from 'react';
import { IgrSplitPaneCollection } from "./igr-split-pane-collection";
import { DockManagerLayout } from "./DockManagerLayout";
import { TypeRegistrar } from "igniteui-react-core";
import { NamePatcher, getModifiedProps, isValidProp, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
import { SplitPaneCollection as SplitPaneCollection_internal } from "./SplitPaneCollection";
import { SplitPane } from "./SplitPane";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
/**
 * Describes a Dock Manager layout.
*/
var IgrDockManagerLayout = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrDockManagerLayout, _super);
    function IgrDockManagerLayout(props) {
        var _this = _super.call(this, props) || this;
        _this._floatingPanes = null;
        _this.__p = null;
        _this._hasUserValues = new Set();
        _this._stylingContainer = null;
        _this._stylingParent = null;
        _this._inStyling = false;
        if (_this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(_this));
        }
        _this._implementation = _this.createImplementation();
        _this._implementation.externalObject = _this;
        _this.onImplementationCreated();
        return _this;
    }
    IgrDockManagerLayout.prototype.createImplementation = function () {
        return new DockManagerLayout();
    };
    Object.defineProperty(IgrDockManagerLayout.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        } /**
                                     * @hidden
                                     */,
        enumerable: false,
        configurable: true
    });
    IgrDockManagerLayout._createFromInternal = function (internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        var name = internal.$type.name;
        var externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    };
    IgrDockManagerLayout.prototype.onImplementationCreated = function () {
    };
    IgrDockManagerLayout.prototype.componentDidMount = function () {
        var e_1, _a;
        try {
            for (var _b = __values(Object.keys(this.props)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = this.props[p];
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
    };
    IgrDockManagerLayout.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var e_2, _a;
        var mod = getModifiedProps(this.props, nextProps);
        try {
            for (var _b = __values(Object.keys(mod)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = mod[p];
                }
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        return true;
    };
    IgrDockManagerLayout.prototype.render = function () {
        return null;
    };
    Object.defineProperty(IgrDockManagerLayout.prototype, "rootPane", {
        /**
         * The root split pane of the layout.
        */
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDockManagerLayout.prototype, "floatingPanes", {
        /**
         * The floating panes of the layout.
        */
        get: function () {
            if (this._floatingPanes === null) {
                var coll = new IgrSplitPaneCollection();
                var innerColl = this.i.b;
                if (!innerColl) {
                    innerColl = new SplitPaneCollection_internal();
                }
                this._floatingPanes = coll._fromInner(innerColl);
                this.i.b = innerColl;
            }
            return this._floatingPanes;
        },
        set: function (v) {
            if (this._floatingPanes !== null) {
                this._floatingPanes._setSyncTarget(null);
                this._floatingPanes = null;
            }
            var coll = new IgrSplitPaneCollection();
            this._floatingPanes = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(SplitPane.$type);
            var innerColl = this.i.b;
            if (!innerColl) {
                innerColl = new SplitPaneCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._floatingPanes._setSyncTarget(syncColl);
            this.i.b = innerColl;
        },
        enumerable: false,
        configurable: true
    });
    IgrDockManagerLayout.prototype.findByName = function (name) {
        if (this.rootPane && this.rootPane.name && this.rootPane.name == name) {
            return this.rootPane;
        }
        if (this.floatingPanes != null && this.floatingPanes.findByName && this.floatingPanes.findByName(name)) {
            return this.floatingPanes.findByName(name);
        }
        return null;
    };
    Object.defineProperty(IgrDockManagerLayout.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: false,
        configurable: true
    });
    IgrDockManagerLayout.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgrDockManagerLayout.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("DockManagerLayout");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this.rootPane && this.rootPane._styling) {
            this.rootPane._styling(container, component, this);
        }
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    return IgrDockManagerLayout;
}(React.Component));
export { IgrDockManagerLayout };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-dock-manager-layout.js <==
import { IgrSplitPane } from "./igr-split-pane";
import { IgrSplitPaneCollection } from "./igr-split-pane-collection";
import { DockManagerLayout as DockManagerLayout_internal } from "./DockManagerLayout";
import { SplitPaneCollection as SplitPaneCollection_internal } from "./SplitPaneCollection";
import { SplitPane } from "./SplitPane";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
/**
 * Describes a Dock Manager layout.
*/
var IgrDockManagerLayout = /** @class */ /*@__PURE__*/ (function () {
    function IgrDockManagerLayout() {
        this._floatingPanes = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrDockManagerLayout.prototype.createImplementation = function () {
        return new DockManagerLayout_internal();
    };
    Object.defineProperty(IgrDockManagerLayout.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrDockManagerLayout.prototype.onImplementationCreated = function () {
    };
    IgrDockManagerLayout.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrDockManagerLayout.prototype, "name", {
        get: function () {
            return this.i.h;
        },
        set: function (v) {
            this.i.h = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDockManagerLayout.prototype, "rootPane", {
        /**
         * The root split pane of the layout.
        */
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrSplitPane._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDockManagerLayout.prototype, "floatingPanes", {
        /**
         * The floating panes of the layout.
        */
        get: function () {
            if (this._floatingPanes === null) {
                var coll = new IgrSplitPaneCollection();
                var innerColl = this.i.b;
                if (!innerColl) {
                    innerColl = new SplitPaneCollection_internal();
                }
                this._floatingPanes = coll._fromInner(innerColl);
            }
            return this._floatingPanes;
        },
        set: function (v) {
            if (this._floatingPanes !== null) {
                this._floatingPanes._setSyncTarget(null);
                this._floatingPanes = null;
            }
            var coll = new IgrSplitPaneCollection();
            this._floatingPanes = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(SplitPane.$type);
            var innerColl = this.i.b;
            if (!innerColl) {
                innerColl = new SplitPaneCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._floatingPanes._setSyncTarget(syncColl);
        },
        enumerable: false,
        configurable: true
    });
    IgrDockManagerLayout.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.rootPane && this.rootPane.name && this.rootPane.name == name) {
            return this.rootPane;
        }
        if (this.floatingPanes != null && this.floatingPanes.findByName && this.floatingPanes.findByName(name)) {
            return this.floatingPanes.findByName(name);
        }
        return null;
    };
    IgrDockManagerLayout.prototype.setNativeElement = function (element) {
        this.i.setNativeElement(element);
    };
    return IgrDockManagerLayout;
}());
export { IgrDockManagerLayout };
